R/data.R
apra_stat_pubs.Rd
This dataset contains a record of all statistical publications produced by APRA that are available in readapra.
readapra
apra_stat_pubs
A data frame with 7 rows and 3 variables:
the full name of the statistical publication.
the acronym of the statistical publication.
available current and historical versions of the statistical publication.